@@ -131,11 +131,7 @@ make_variable_entry(MathVariablePopup *popup, const gchar *name, const MPNumber
     GtkWidget *hbox, *button, *label;
     gchar *text;
 
-#if GTK_CHECK_VERSION (3, 2, 0)
     hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
-#else
-    hbox = gtk_hbox_new(FALSE, 6);
-#endif
 
     if (value)
     {
@@ -156,7 +152,7 @@ make_variable_entry(MathVariablePopup *popup, const gchar *name, const MPNumber
     label = gtk_label_new(text);
     g_free(text);
     gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
     gtk_container_add(GTK_CONTAINER(button), label);
     gtk_widget_show(label);
 
@@ -215,11 +211,7 @@ math_variable_popup_set_property(GObject      *object,
         }
         g_strfreev(names);
 
-#if GTK_CHECK_VERSION (3, 2, 0)
         entry = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
-#else
-        entry = gtk_hbox_new(FALSE, 6);
-#endif
         gtk_widget_show(entry);
 
         // TODO: Show greyed "variable name" text to give user a hint how to use
@@ -309,11 +301,7 @@ math_variable_popup_init(MathVariablePopup *popup)
     /* Destroy this window when it loses focus */
     g_signal_connect(G_OBJECT(popup), "focus-out-event", G_CALLBACK(variable_focus_out_event_cb), popup);
 
-#if GTK_CHECK_VERSION (3, 2, 0)
     popup->priv->vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 6);
-#else
-    popup->priv->vbox = gtk_vbox_new(FALSE, 6);
-#endif
     gtk_box_set_homogeneous(GTK_BOX(popup->priv->vbox), TRUE);
     gtk_container_add(GTK_CONTAINER(popup), popup->priv->vbox);
     gtk_widget_show(popup->priv->vbox);
