@@ -17,8 +17,6 @@
 #include "utility.h"
 
 // gtk3 hack
-#if !GTK_CHECK_VERSION (3, 0, 0)
-
 	#ifndef GDK_KEY_F1
 		#define GDK_KEY_F1 GDK_F1
 	#endif
@@ -31,13 +29,6 @@
 		#define GDK_KEY_Z GDK_z
 	#endif
 
-#else // gtk 3.0.0
-
-	#define gtk_vbox_new(x,y) \
-		gtk_box_new(GTK_ORIENTATION_VERTICAL, y)
-
-#endif
-
 enum {
     PROP_0,
     PROP_EQUATION
@@ -248,7 +239,7 @@ static void about_cb(GtkWidget* widget, MathWindow* window)
 
     char copyright[] = \
         "Copyright \xc2\xa9 1986–2010 The GCalctool authors\n"
-        "Copyright \xc2\xa9 2011-2012 MATE developers";
+        "Copyright \xc2\xa9 2011-2017 MATE developers";
 
     /* The license this software is under (GPL2+) */
     char* license = _("mate-calc is free software; you can redistribute it and/or modify\n"
@@ -424,7 +415,7 @@ create_gui(MathWindow *window)
     GtkWidget *main_vbox, *vbox;
     GtkWidget *scrolled_window;
 
-    main_vbox = gtk_vbox_new(FALSE, 0);
+    main_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
     gtk_container_add(GTK_CONTAINER(window), main_vbox);
     gtk_widget_show(main_vbox);
 
@@ -434,7 +425,7 @@ create_gui(MathWindow *window)
 
     create_menu(window);
 
-    vbox = gtk_vbox_new(FALSE, 6);
+    vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 6);
     gtk_container_set_border_width(GTK_CONTAINER(vbox), 6);
     gtk_box_pack_start(GTK_BOX(main_vbox), vbox, TRUE, TRUE, 0);  
     gtk_widget_show(vbox);
